diff --git a/wp-includes/version.php b/wp-includes/version.php
index 336898b3b0..076293c19d 100644
--- a/wp-includes/version.php
+++ b/wp-includes/version.php
@@ -4,7 +4,7 @@
*
* @global string $wp_version
*/
-$wp_version = '4.2-alpha-31074';
+$wp_version = '4.2-alpha-31075';
/**
* Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
diff --git a/wp-admin/includes/dashboard.php b/wp-admin/includes/dashboard.php
index bf37176bae..70bfa6e2a3 100644
--- a/wp-admin/includes/dashboard.php
+++ b/wp-admin/includes/dashboard.php
@@ -715,15 +715,12 @@ function wp_dashboard_recent_posts( $args ) {
$relative = date_i18n( __( 'M jS' ), $time );
}
- if ( current_user_can( 'edit_post', get_the_ID() ) ) {
- /* translators: 1: relative date, 2: time, 3: post edit link, 4: post title */
- $format = __( '%1$s, %2$s %4$s' );
- printf( "
$format", $relative, get_the_time(), get_edit_post_link(), _draft_or_post_title() );
- } else {
- /* translators: 1: relative date, 2: time, 3: post title */
- $format = __( '%1$s, %2$s %3$s' );
- printf( "$format", $relative, get_the_time(), _draft_or_post_title() );
- }
+ // Use the post edit link for those who can edit, the permalink otherwise.
+ $recent_post_link = current_user_can( 'edit_post', get_the_ID() ) ? get_edit_post_link() : get_permalink();
+
+ /* translators: 1: relative date, 2: time, 3: post edit link or permalink, 4: post title */
+ $format = __( '%1$s, %2$s %4$s' );
+ printf( "$format", $relative, get_the_time(), $recent_post_link, _draft_or_post_title() );
}
echo '';